const fs = require('fs').promises;
const path = require('path');
const { execSync } = require('child_process');

const packagePath = path.resolve(__dirname, 'package.json');

async function runBuild() {
    const packageJSON = JSON.parse(await fs.readFile(packagePath, 'utf8'));
    const originalMain = packageJSON.main;
    const originalTypes = packageJSON.types;
    const originalModule = packageJSON.module; // Storing original module property

    packageJSON.types = './dist/package.d.ts';

    await fs.writeFile(packagePath, JSON.stringify(packageJSON, null, 2), 'utf8');

    try {
        execSync('vite build', { stdio: 'inherit' });
    } finally {
        packageJSON.main = "./package.ts";
        packageJSON.types = "./package.ts";

        // Restore the module property to its original state
        if (originalModule) {
            packageJSON.module = originalModule;
        } else {
            // If the original package.json did not have a module property, delete it.
            delete packageJSON.module;
        }

        await fs.writeFile(packagePath, JSON.stringify(packageJSON, null, 2), 'utf8');
    }
}

runBuild();
